@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "collectionaclwidget.h"
@@ -39,7 +27,6 @@ class ActionButton : public QPushButton
 public:
     ActionButton(QWidget *parent = nullptr)
         : QPushButton(parent)
-        , mDefaultAction(nullptr)
     {
     }
 
@@ -82,11 +69,11 @@ CollectionAclWidget::CollectionAclWidget(QWidget *parent)
     : QWidget(parent)
     , mAclManager(new PimCommon::AclManager(this))
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    QVBoxLayout *listViewLayout = new QVBoxLayout;
+    auto layout = new QHBoxLayout(this);
+    auto listViewLayout = new QVBoxLayout;
     layout->addLayout(listViewLayout);
 
-    AclListView *view = new AclListView;
+    auto view = new AclListView;
     view->setObjectName(QStringLiteral("list_view"));
     listViewLayout->addWidget(view);
     mRecursiveChk = new QCheckBox(i18n("Apply permissions on all &subfolders."), this);
@@ -97,12 +84,12 @@ CollectionAclWidget::CollectionAclWidget(QWidget *parent)
     view->setModel(mAclManager->model());
     view->setSelectionModel(mAclManager->selectionModel());
 
-    QWidget *buttonBox = new QWidget;
-    QVBoxLayout *buttonBoxVBoxLayout = new QVBoxLayout(buttonBox);
+    auto buttonBox = new QWidget;
+    auto buttonBoxVBoxLayout = new QVBoxLayout(buttonBox);
     buttonBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(buttonBox);
 
-    ActionButton *button = new ActionButton(buttonBox);
+    auto button = new ActionButton(buttonBox);
     buttonBoxVBoxLayout->addWidget(button);
     button->setObjectName(QStringLiteral("add"));
     button->setDefaultAction(mAclManager->addAction());
@@ -117,7 +104,7 @@ CollectionAclWidget::CollectionAclWidget(QWidget *parent)
     button->setDefaultAction(mAclManager->deleteAction());
     button->setObjectName(QStringLiteral("delete"));
 
-    QWidget *spacer = new QWidget(buttonBox);
+    auto spacer = new QWidget(buttonBox);
     buttonBoxVBoxLayout->addWidget(spacer);
     spacer->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
     connect(view, SIGNAL(doubleClicked(QModelIndex)), mAclManager->editAction(), SIGNAL(triggered()));
